Struct cumulus_pallet_parachain_system::pallet::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn set_validation_data(
origin: OriginFor<T>,
data: ParachainInherentData
) -> DispatchResultWithPostInfo
pub fn set_validation_data(
origin: OriginFor<T>,
data: ParachainInherentData
) -> DispatchResultWithPostInfo
Set the current validation data.
This should be invoked exactly once per block. It will panic at the finalization phase if the call was not invoked.
The dispatch origin for this call must be Inherent
As a side effect, this function upgrades the current validation function if the appropriate time has come.
pub fn sudo_send_upward_message(
origin: OriginFor<T>,
message: UpwardMessage
) -> DispatchResult
In case of a scheduled upgrade, this storage field contains the validation code to be applied.
As soon as the relay chain gives us the go-ahead signal, we will overwrite the :code
which will result the next block process with the new validation code. This concludes the upgrade process.
The PersistedValidationData set for this block.
This value is expected to be set only once per block and it’s never stored
in the trie.
The snapshot of some state related to messaging relevant to the current parachain as per the relay parent.
This field is meant to be updated each block with the validation data inherent. Therefore,
before processing of the inherent, e.g. in on_initialize this data may be stale.
This data is also absent from the genesis.
The parachain host configuration that was obtained from the relay parent.
This field is meant to be updated each block with the validation data inherent. Therefore,
before processing of the inherent, e.g. in on_initialize this data may be stale.
This data is also absent from the genesis.
The maximum code size permitted, in bytes.
Returns None if the relay chain parachain host configuration hasn’t been submitted yet.
Returns the CollationInfo of the current active block.
This is expected to be used by the
CollectCollationInfo runtime api.