Struct cumulus_pallet_parachain_system::RelayChainStateProof [−][src]
pub struct RelayChainStateProof { /* fields omitted */ }Expand description
A state proof extracted from the relay chain.
This state proof is extracted from the relay chain block we are building on top of.
Implementations
Create a new instance of Self.
Returns an error if the given relay_parent_storage_root is not the root of the given
proof.
Read the [MessagingStateSnapshot] from the relay chain state proof.
Returns an error if anything failed at reading or decoding.
Read the AbridgedHostConfiguration from the relay chain state proof.
Returns an error if anything failed at reading or decoding.
Read the Slot from the relay chain state proof.
The slot is slot of the relay chain block this state proof was extracted from.
Returns an error if anything failed at reading or decoding.
Read the go-ahead signal for the upgrade from the relay chain state proof.
The go-ahead specifies whether the parachain can apply the upgrade or should abort it. If the value is absent then there is either no judgment by the relay chain yet or no upgrade is pending.
Returns an error if anything failed at reading or decoding.
Read the upgrade restriction signal for the upgrade from the relay chain state proof.
If the upgrade restriction is not None, then the parachain cannot signal an upgrade at
this block.
Returns an error if anything failed at reading or decoding.